@@ -1,12 +1,14 @@
 //! Filesystem API constants, translated into `bitflags` constants.
 
+use crate::fs::RawMode;
 use bitflags::bitflags;
-#[cfg(linux_raw)]
-use linux_raw_sys::general::__kernel_mode_t;
 
 #[cfg(libc)]
 bitflags! {
-    /// `FD_*` constants.
+    /// `FD_*` constants for use with [`fcntl_getfd`] and [`fcntl_setfd`].
+    ///
+    /// [`fcntl_getfd`]: crate::fs::fcntl_getfd
+    /// [`fcntl_setfd`]: crate::fs::fcntl_setfd
     pub struct FdFlags: libc::c_int {
         /// `FD_CLOEXEC`
         const CLOEXEC = libc::FD_CLOEXEC;
@@ -15,7 +17,10 @@ bitflags! {
 
 #[cfg(linux_raw)]
 bitflags! {
-    /// `FD_*` constants.
+    /// `FD_*` constants for use with [`fcntl_getfd`] and [`fcntl_setfd`].
+    ///
+    /// [`fcntl_getfd`]: crate::fs::fcntl_getfd
+    /// [`fcntl_setfd`]: crate::fs::fcntl_setfd
     pub struct FdFlags: std::os::raw::c_uint {
         /// `FD_CLOEXEC`
         const CLOEXEC = linux_raw_sys::general::FD_CLOEXEC;
@@ -64,7 +69,11 @@ bitflags! {
 
 #[cfg(all(libc, not(target_os = "redox")))]
 bitflags! {
-    /// `AT_*` constants.
+    /// `AT_*` constants for use with [`openat`], [`statat`], and other `*at`
+    /// functions.
+    ///
+    /// [`openat`]: crate::fs::openat
+    /// [`statat`]: crate::fs::statat
     pub struct AtFlags: libc::c_int {
         /// `AT_REMOVEDIR`
         const REMOVEDIR = libc::AT_REMOVEDIR;
@@ -91,7 +100,11 @@ bitflags! {
 
 #[cfg(linux_raw)]
 bitflags! {
-    /// `AT_*` constants.
+    /// `AT_*` constants for use with [`openat`], [`statat`], and other `*at`
+    /// functions.
+    ///
+    /// [`openat`]: crate::fs::openat
+    /// [`statat`]: crate::fs::statat
     pub struct AtFlags: std::os::raw::c_uint {
         /// `AT_REMOVEDIR`
         const REMOVEDIR = linux_raw_sys::general::AT_REMOVEDIR;
@@ -112,8 +125,10 @@ bitflags! {
 
 #[cfg(libc)]
 bitflags! {
-    /// `S_I*` constants.
-    pub struct Mode: libc::mode_t {
+    /// `S_I*` constants for use with [`openat`].
+    ///
+    /// [`openat`]: crate::fs::openat
+    pub struct Mode: RawMode {
         /// `S_IRWXU`
         #[cfg(not(target_os = "wasi"))] // WASI doesn't have Unix-style mode flags.
         const IRWXU = libc::S_IRWXU;
@@ -196,84 +211,94 @@ bitflags! {
 
         /// `S_IFBLK`
         const IFBLK = libc::S_IFBLK;
+
+        /// `S_IFMT`
+        const IFMT = libc::S_IFMT;
     }
 }
 
 #[cfg(linux_raw)]
 bitflags! {
-    /// `S_I*` constants.
-    pub struct Mode: __kernel_mode_t {
+    /// `S_I*` constants for use with [`openat`].
+    ///
+    /// [`openat`]: crate::fs::openat
+    pub struct Mode: RawMode {
         /// `S_IRWXU`
-        const IRWXU = linux_raw_sys::general::S_IRWXU as __kernel_mode_t;
+        const IRWXU = linux_raw_sys::general::S_IRWXU;
 
         /// `S_IRUSR`
-        const IRUSR = linux_raw_sys::general::S_IRUSR as __kernel_mode_t;
+        const IRUSR = linux_raw_sys::general::S_IRUSR;
 
         /// `S_IWUSR`
-        const IWUSR = linux_raw_sys::general::S_IWUSR as __kernel_mode_t;
+        const IWUSR = linux_raw_sys::general::S_IWUSR;
 
         /// `S_IXUSR`
-        const IXUSR = linux_raw_sys::general::S_IXUSR as __kernel_mode_t;
+        const IXUSR = linux_raw_sys::general::S_IXUSR;
 
         /// `S_IRWXG`
-        const IRWXG = linux_raw_sys::general::S_IRWXG as __kernel_mode_t;
+        const IRWXG = linux_raw_sys::general::S_IRWXG;
 
         /// `S_IRGRP`
-        const IRGRP = linux_raw_sys::general::S_IRGRP as __kernel_mode_t;
+        const IRGRP = linux_raw_sys::general::S_IRGRP;
 
         /// `S_IWGRP`
-        const IWGRP = linux_raw_sys::general::S_IWGRP as __kernel_mode_t;
+        const IWGRP = linux_raw_sys::general::S_IWGRP;
 
         /// `S_IXGRP`
-        const IXGRP = linux_raw_sys::general::S_IXGRP as __kernel_mode_t;
+        const IXGRP = linux_raw_sys::general::S_IXGRP;
 
         /// `S_IRWXO`
-        const IRWXO = linux_raw_sys::general::S_IRWXO as __kernel_mode_t;
+        const IRWXO = linux_raw_sys::general::S_IRWXO;
 
         /// `S_IROTH`
-        const IROTH = linux_raw_sys::general::S_IROTH as __kernel_mode_t;
+        const IROTH = linux_raw_sys::general::S_IROTH;
 
         /// `S_IWOTH`
-        const IWOTH = linux_raw_sys::general::S_IWOTH as __kernel_mode_t;
+        const IWOTH = linux_raw_sys::general::S_IWOTH;
 
         /// `S_IXOTH`
-        const IXOTH = linux_raw_sys::general::S_IXOTH as __kernel_mode_t;
+        const IXOTH = linux_raw_sys::general::S_IXOTH;
 
         /// `S_ISUID`
-        const ISUID = linux_raw_sys::general::S_ISUID as __kernel_mode_t;
+        const ISUID = linux_raw_sys::general::S_ISUID;
 
         /// `S_ISGID`
-        const ISGID = linux_raw_sys::general::S_ISGID as __kernel_mode_t;
+        const ISGID = linux_raw_sys::general::S_ISGID;
 
         /// `S_ISVTX`
-        const ISVTX = linux_raw_sys::general::S_ISVTX as __kernel_mode_t;
+        const ISVTX = linux_raw_sys::general::S_ISVTX;
 
         /// `S_IFREG`
-        const IFREG = linux_raw_sys::general::S_IFREG as __kernel_mode_t;
+        const IFREG = linux_raw_sys::general::S_IFREG;
 
         /// `S_IFDIR`
-        const IFDIR = linux_raw_sys::general::S_IFDIR as __kernel_mode_t;
+        const IFDIR = linux_raw_sys::general::S_IFDIR;
 
         /// `S_IFLNK`
-        const IFLNK = linux_raw_sys::general::S_IFLNK as __kernel_mode_t;
+        const IFLNK = linux_raw_sys::general::S_IFLNK;
 
         /// `S_IFIFO`
-        const IFIFO = linux_raw_sys::general::S_IFIFO as __kernel_mode_t;
+        const IFIFO = linux_raw_sys::general::S_IFIFO;
 
         /// `S_IFSOCK`
-        const IFSOCK = linux_raw_sys::general::S_IFSOCK as __kernel_mode_t;
+        const IFSOCK = linux_raw_sys::general::S_IFSOCK;
 
         /// `S_IFCHR`
-        const IFCHR = linux_raw_sys::general::S_IFCHR as __kernel_mode_t;
+        const IFCHR = linux_raw_sys::general::S_IFCHR;
 
         /// `S_IFBLK`
-        const IFBLK = linux_raw_sys::general::S_IFBLK as __kernel_mode_t;
+        const IFBLK = linux_raw_sys::general::S_IFBLK;
+
+        /// `S_IFMT`
+        const IFMT = linux_raw_sys::general::S_IFMT;
     }
 }
 
 #[cfg(libc)]
 bitflags! {
-    /// `O_*` constants.
+    /// `O_*` constants for use with [`openat`].
+    ///
+    /// [`openat`]: crate::fs::openat
     pub struct OFlags: libc::c_int {
         /// `O_ACCMODE`
         const ACCMODE = libc::O_ACCMODE;
@@ -386,7 +411,9 @@ bitflags! {
 
 #[cfg(linux_raw)]
 bitflags! {
-    /// `O_*` constants.
+    /// `O_*` constants for use with [`openat`].
+    ///
+    /// [`openat`]: crate::fs::openat
     pub struct OFlags: std::os::raw::c_uint {
         /// `O_ACCMODE`
         const ACCMODE = linux_raw_sys::general::O_ACCMODE;
@@ -460,7 +487,9 @@ bitflags! {
 
 #[cfg(any(target_os = "ios", target_os = "macos"))]
 bitflags! {
-    /// `CLONE_*` constants.
+    /// `CLONE_*` constants for use with [`fclonefileat`].
+    ///
+    /// [`fclonefileat`]: crate::fs::fclonefileat
     pub struct CloneFlags: libc::c_int {
         /// `CLONE_NOFOLLOW`
         const NOFOLLOW = 1;
@@ -510,7 +539,9 @@ bitflags! {
 
 #[cfg(all(libc, any(target_os = "android", target_os = "linux")))]
 bitflags! {
-    /// `RESOLVE_*` constants.
+    /// `RESOLVE_*` constants for use with [`openat2`].
+    ///
+    /// [`openat2`]: crate::fs::openat2
     pub struct ResolveFlags: u64 {
         /// `RESOLVE_NO_MAGICLINKS`
         const NO_MAGICLINKS = 0x02;
@@ -522,7 +553,9 @@ bitflags! {
 
 #[cfg(linux_raw)]
 bitflags! {
-    /// `RESOLVE_*` constants.
+    /// `RESOLVE_*` constants for use with [`openat2`].
+    ///
+    /// [`openat2`]: crate::fs::openat2
     pub struct ResolveFlags: u64 {
         /// `RESOLVE_NO_MAGICLINKS`
         const NO_MAGICLINKS = linux_raw_sys::v5_11::general::RESOLVE_NO_MAGICLINKS as u64;
