@@ -1,17 +1,19 @@
+use crate::fs::Dev;
+
 /// `makedev(maj, min)`
 #[cfg(all(
     libc,
     not(any(target_os = "android", target_os = "emscripten", target_os = "wasi"))
 ))]
 #[inline]
-pub fn makedev(maj: u32, min: u32) -> u64 {
+pub fn makedev(maj: u32, min: u32) -> Dev {
     unsafe { libc::makedev(maj, min) }
 }
 
 /// `makedev(maj, min)`
 #[cfg(all(libc, target_os = "android"))]
 #[inline]
-pub fn makedev(maj: u32, min: u32) -> u64 {
+pub fn makedev(maj: u32, min: u32) -> Dev {
     // Android's `makedev` oddly has signed argument types.
     unsafe { libc::makedev(maj as i32, min as i32) }
 }
@@ -19,15 +21,15 @@ pub fn makedev(maj: u32, min: u32) -> u64 {
 /// `makedev(maj, min)`
 #[cfg(target_os = "emscripten")]
 #[inline]
-pub fn makedev(maj: u32, min: u32) -> u64 {
+pub fn makedev(maj: u32, min: u32) -> Dev {
     // Emscripten's `makedev` has a 32-bit return value.
-    u64::from(unsafe { libc::makedev(maj, min) })
+    Dev::from(unsafe { libc::makedev(maj, min) })
 }
 
 /// `makedev(maj, min)`
 #[cfg(linux_raw)]
 #[inline]
-pub fn makedev(maj: u32, min: u32) -> u64 {
+pub fn makedev(maj: u32, min: u32) -> Dev {
     ((u64::from(maj) & 0xfffff000_u64) << 32)
         | ((u64::from(maj) & 0x00000fff_u64) << 8)
         | ((u64::from(min) & 0xffffff00_u64) << 12)
@@ -40,14 +42,14 @@ pub fn makedev(maj: u32, min: u32) -> u64 {
     not(any(target_os = "android", target_os = "emscripten", target_os = "wasi"))
 ))]
 #[inline]
-pub fn major(dev: u64) -> u32 {
+pub fn major(dev: Dev) -> u32 {
     unsafe { libc::major(dev) }
 }
 
 /// `major(dev)`
 #[cfg(all(libc, target_os = "android"))]
 #[inline]
-pub fn major(dev: u64) -> u32 {
+pub fn major(dev: Dev) -> u32 {
     // Android's `major` oddly has signed return types.
     (unsafe { libc::major(dev) }) as u32
 }
@@ -55,7 +57,7 @@ pub fn major(dev: u64) -> u32 {
 /// `major(dev)`
 #[cfg(target_os = "emscripten")]
 #[inline]
-pub fn major(dev: u64) -> u32 {
+pub fn major(dev: Dev) -> u32 {
     // Emscripten's `major` has a 32-bit argument value.
     unsafe { libc::major(dev as u32) }
 }
@@ -63,7 +65,7 @@ pub fn major(dev: u64) -> u32 {
 /// `major(dev)`
 #[cfg(linux_raw)]
 #[inline]
-pub fn major(dev: u64) -> u32 {
+pub fn major(dev: Dev) -> u32 {
     (((dev >> 31 >> 1) & 0xfffff000) | ((dev >> 8) & 0x00000fff)) as u32
 }
 
@@ -73,14 +75,14 @@ pub fn major(dev: u64) -> u32 {
     not(any(target_os = "android", target_os = "emscripten", target_os = "wasi"))
 ))]
 #[inline]
-pub fn minor(dev: u64) -> u32 {
+pub fn minor(dev: Dev) -> u32 {
     unsafe { libc::minor(dev) }
 }
 
 /// `minor(dev)`
 #[cfg(all(libc, target_os = "android"))]
 #[inline]
-pub fn minor(dev: u64) -> u32 {
+pub fn minor(dev: Dev) -> u32 {
     // Android's `minor` oddly has signed return types.
     (unsafe { libc::minor(dev) }) as u32
 }
@@ -88,7 +90,7 @@ pub fn minor(dev: u64) -> u32 {
 /// `minor(dev)`
 #[cfg(target_os = "emscripten")]
 #[inline]
-pub fn minor(dev: u64) -> u32 {
+pub fn minor(dev: Dev) -> u32 {
     // Emscripten's `minor` has a 32-bit argument value.
     unsafe { libc::minor(dev as u32) }
 }
@@ -96,7 +98,7 @@ pub fn minor(dev: u64) -> u32 {
 /// `minor(dev)`
 #[cfg(linux_raw)]
 #[inline]
-pub fn minor(dev: u64) -> u32 {
+pub fn minor(dev: Dev) -> u32 {
     (((dev >> 12) & 0xffffff00) | (dev & 0x000000ff)) as u32
 }
 
