@@ -111,8 +111,8 @@ bitflags! {
 /// Note that this isn't available on Linux before 4.11; returns `ENOSYS` in
 /// that case.
 #[inline]
-pub fn statx<'f, P: path::Arg, Fd: AsFd<'f>>(
-    dirfd: Fd,
+pub fn statx<'f, P: path::Arg, Fd: AsFd>(
+    dirfd: &Fd,
     path: P,
     flags: AtFlags,
     mask: StatxFlags,
