@@ -5,7 +5,7 @@ use unsafe_io::os::posish::AsRawFd;
 
 /// `fcntl(fd, F_RDADVISE, radvisory { offset, len })`
 #[inline]
-pub fn rdadvise<'f, Fd: AsFd<'f>>(fd: Fd, offset: u64, len: u64) -> io::Result<()> {
+pub fn rdadvise<Fd: AsFd>(fd: &Fd, offset: u64, len: u64) -> io::Result<()> {
     let fd = fd.as_fd();
     _rdadvise(fd, offset, len)
 }
