@@ -5,10 +5,10 @@ mod clock;
 
 // TODO: Convert WASI'S clock APIs to use handles rather than ambient
 // clock identifiers, update `wasi-libc`, and then add support in `posish`.
-#[cfg(not(target_os = "redox"))]
-pub use clock::nanosleep;
 #[cfg(not(any(target_os = "wasi", target_os = "redox")))]
 pub use clock::{clock_getres, clock_gettime, ClockId};
+#[cfg(not(target_os = "redox"))]
+pub use clock::{nanosleep, NanosleepRelativeResult};
 
 #[cfg(not(any(
     target_os = "macos",
@@ -22,10 +22,10 @@ pub use clock::{clock_getres, clock_gettime, ClockId};
 )))]
 pub use clock::{clock_nanosleep_absolute, clock_nanosleep_relative};
 
-/// Re-export `timespec`.
+/// `struct timespec`
 #[cfg(libc)]
 pub type Timespec = libc::timespec;
 
-/// Re-export `timespec`.
+/// `struct timespec`.
 #[cfg(linux_raw)]
-pub type Timespec = linux_raw_sys::v5_4::general::__kernel_timespec;
+pub type Timespec = linux_raw_sys::general::__kernel_timespec;
